/*
 * Simple library for string transliterateion between English and
 * Berndese languages.
 *
 * Usage:
 * var berndese = new Berndese();
 * var result = berndese.translate("english", "string");
 */


class Berndese {
    constructor() {
        // Translation tables
        this.table = [
            ['bk^k', 'q'],
            ['k^k', 'w'],
            ['zbr', 'x'],
            ['z^k', 'y'],
            ['ee', 'th'],
            ['aa', 'ng'],
            ['noo', 'ch'],
            ['oo', 'sh'],
            ['p', 'ph'],
            ['p', 'f'],
            ['b', 'k'],
            ['b', 'c'],
            ['q', 'a'],
            ['z', 'e'],
            ['x', 'i'],
            ['j', 'o'],
            ['k', 'u'],
            ['v', 'b'],
            ['w', 'd'],
            ['m', 'g'],
            ['g', 'h'],
            ['c', 'j'],
            ['f', 'l'],
            ['l', 'm'],
            ['d', 'n'],
            ['h', 'p'],
            ['s', 'r'],
            ['r', 's'],
            ['n', 't'],
            ['t', 'v'],
            ['i', 'z'],
            ['^', '^'],
        ];

        this.maps = {'berndese': {},
                     'english': {}};

        this.table.forEach((pair) => {
            this.maps.berndese[pair[0]] = pair[1];
            this.maps.english[pair[1]] = pair[0];
        });

        // Create replace regexes
        this.regexes = {};
        Object.keys(this.maps).forEach((lang) => {
            this.regexes[lang] = new RegExp(
                Object.keys(this.maps[lang]).map((c) => {
                    if (c.indexOf('^') !== -1)
                        return c.replace('\^', '\\^');
                    return c;
                }).join('|'),
                'gi'
            );
        });
    }

    // Get an array of language names
    get languages() {
        return Object.keys(this.maps);
    }

    // Translate string from language
    translate(fromLang, string) {
        return string.replace(this.regexes[fromLang], (c) => {
            const ch = c.toLowerCase()
            if (this.maps[fromLang].hasOwnProperty(ch))
                return this.maps[fromLang][ch];
            return '';
        });
    }
}
